
# Type: repr


the name of the python object that implements this type definition

URI: [meta:repr](https://w3id.org/biolink/biolinkml/meta/repr)


## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value=None, description=None) |

